<?php
/*
* Plugin Name: Event Organiser NGO
* Plugin URI: http://ngo-portal.org
* Description:  Add on to the Event organiser plugin to show member-sites event in the portal  calendar +  2 calendar widgets for member sites and a calendar widget for the portal site. Should be network enabled, along with Event Organiser.
* Version: 1.2.4
* Author: George Bredberg
* Author URI: http://datagaraget.se
* Text Domain: event-organiser-ngo
* Domain Path: /languages
* License GPLv2 or later
* License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

// Prevent direct access to this file.
if ( ! defined( 'ABSPATH' ) ) {
	header( 'HTTP/1.0 403 Forbidden' );
	echo 'This file should not be accessed directly!';
	exit; // Exit if accessed directly
}

// Load translation
add_action( 'plugins_loaded', 'eongo_load_plugin_textdomain' );
function eongo_load_plugin_textdomain() {
	load_plugin_textdomain( 'event-organiser-ngo', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
}

// Check if mother-plugin is installed and activated. If not, deactivate this plugin and print an error message.
add_action( 'admin_init', 'eongo_plugin_has_parent_plugin' );
function eongo_plugin_has_parent_plugin() {
	$req_plugin = 'event-organiser/event-organiser.php';
	if ( is_admin() && current_user_can( 'activate_plugins' ) &&  !is_plugin_active( $req_plugin ) ) {
		add_action( 'admin_notices', 'eongo_plugin_notice' );
		deactivate_plugins( plugin_basename( __FILE__ ) );

		if ( isset( $_GET['activate'] ) ) {
			unset( $_GET['activate'] );
		}
	}
}

function eongo_plugin_notice(){
	?><div class="error"><p><?php_e( 'The plugin Event Organiser NGOs ad on requires that the plugin "Event Organiser" is installed and enabled before enabling it. Disabling the Event Organiser will disable Event Organiser NGO.', 'event-organiser-ngo' ); ?></p></div><?php
}
// Done complaining about missing plugin...

// -> If plugin get enabled -> run this for all blogs user roles except admin.
register_activation_hook( __FILE__, 'eongo_set_auth' );
// -> If new blog is created, run this for all user roles in the newly created blog using 'wpmu_new_blog' at returned blog id
if( function_exists ( 'wpmu_new_blog' ) ) {
	wpmu_new_blog( __FILE__, 'eongo_set_auth' );
}
//eongo_set_auth(); //Debug

function eongo_set_auth() {
	global $wp_roles;

	if ( ! isset( $wp_roles ) ) {
		$wp_roles = new WP_Roles();
	}

	// Query all blogs from multi-site install
	$blogs = wp_get_sites();

	foreach( $blogs as $blog) {
		switch_to_blog($blog['blog_id']);

		$roles = $wp_roles->get_names();
		$capabilities = array( 'edit_events', 'publish_events', 'delete_events', 'edit_others_events', 'delete_others_events', 'read_private_events', 'manage_venues', 'manage_event_categories' );

		foreach($roles as $role) {
			if ( $role != 'Administrator') {
				$role = strtolower($role);
				foreach ( $capabilities as $capability ) {
					if(method_exists($wp_roles,'remove_cap')) {
						$wp_roles->remove_cap($role, $capability);
					}
				}
			}
		}
		restore_current_blog();
	}
}
////////////////////////////////* Clean up WP-admin menu *///////////////////////////////////
if(!function_exists('wp_get_current_user')) { require_once(ABSPATH . "wp-includes/pluggable.php"); }

add_action( 'wp_loaded', 'eongo_cleanup' );

function eongo_cleanup() {
	if (!(current_user_can('manage_options'))) {
	add_action( 'admin_menu', 'ngo_remove_eo' );
	}

	if(!is_super_admin()){
	add_action( 'admin_menu', 'ngo_remove_eosubmenu', 99 );
	add_action( 'do_meta_boxes', 'remove_eopost_custom_fields' );
	}
}

function ngo_remove_eo() {
	remove_menu_page( 'edit.php?post_type=event' );
}

// Event organiser - Removes submenu items in WP-admin
function ngo_remove_eosubmenu(){
	remove_submenu_page('edit.php?post_type=event','debug'); //Events - System info
	remove_submenu_page('edit.php?post_type=event','eo-addons'); //Events - Extensions
// FIX: How to remove Settings -> Event organiser -> tab permalinks and tab Import/Export?
// remove entire settings - event organiser for everyone except super admin for now.
	remove_submenu_page('options-general.php','event-settings');  //settings -> event organiser
}

// Event organiser - Deactivate custom field
function remove_eopost_custom_fields(){
	remove_meta_box('postcustom', 'event', 'normal');
}

// These widgets could be usefull, but maybe confusing?
function ngo_unregister_eo_widgets() {
	unregister_widget('EO_Events_Agenda_Widget');
	unregister_widget('EO_Event_List_Widget');
	unregister_widget('EO_Calendar_Widget');
	unregister_widget('EO_Widget_Categories');
	unregister_widget('EO_Widget_Venues');
}
// add_action('widgets_init', 'ngo_unregister_eo_widgets', 11); // Let's keep these until we see if they are confusing or not.
/////////////////////////////* Done cleaning up menu *///////////////////////////////////

// Some css for calendar widgets
add_action( 'wp_enqueue_scripts', 'eongo_calendar_style', 15 );
function eongo_calendar_style() {
	wp_enqueue_style( 'eongo_calendar_stylesheet', plugins_url('css/calendar_style.css', __FILE__) );
}

// Load scripts according to if we are on the network site, or not.
add_action( 'plugins_loaded', 'eongo_get_site_functions' );
function eongo_get_site_functions() {
	$portal_site = get_current_site();
	$site_id = get_current_blog_id();

	if( $portal_site->id == $site_id ) {
		// We are on the network site, load portal ad on
		require_once( plugin_dir_path( __FILE__ ).'includes/event-organiser-portal.php' );
		// Load fullpage network calendar
		require_once( plugin_dir_path( __FILE__ ).'includes/event-organiser-portal_cal.php' );
	}
	else {
		// We are on a sub-site, load ngo ad on
		require_once( plugin_dir_path( __FILE__ ).'includes/event-organiser-sites.php' );
	}
}