<?php
// + ACTIONS AND FILTERS
// ===========================================================
add_action('admin_init', 'eop_settings_api_init'										);	// Show events Yes/No
add_action('pre_get_posts','eop_alter_main_page',5,1);
add_action('add_meta_boxes', 'eop_event_box'                       );  // Custom Meta - Events on Portal
add_action('save_post', 'eop_cal_event_save_box'                       );  // Custom Meta - Save events on Portal

// ------------------------------------------------------------------
// Show events in feed -> settings - read
// ------------------------------------------------------------------
function eop_settings_api_init() {
	// Add the section to reading settings so we can add our fields to it
	add_settings_section('eop_setting_section',
		__( 'Events', 'event-organiser-ngo' ),
		'eop_setting_section_callback_function',
		'reading');

	// Add the field with the name	and function to use for our new settings and put it in our new section
	add_settings_field('ngo_show_events',
		__( 'Show events in the feed', 'event-organiser-ngo' ),
		'eop_setting_callback_function',
		'reading',
		'eop_setting_section');

	// Register our setting so that $_POST handling is done for us and
	// our callback function just has to echo the <input>
	register_setting('reading','ngo_show_events');
}

// ------------------------------------------------------------------
// Settings section callback function
// ------------------------------------------------------------------
// This function is needed if we add a new section. This function
// will be run at the start of our section

function eop_setting_section_callback_function() {
	?><p><?php _e( 'Settings for events', 'event-organiser-ngo' ); ?></p><?php
}

function eop_setting_callback_function() {
	?><input name="ngo_show_events" id="show_events_in_feed" type="checkbox" value="1" class="code" <?php echo checked( 1, get_option('ngo_show_events'), false ); ?> /> <?php _e( 'Check if you want to show events in the feed.', 'event-organiser-ngo' );
}

function eop_alter_main_page($query){
	if ( get_option('ngo_show_events') == 1) :
		if( $query->is_main_query() && is_front_page() ){
				$query->set('post_type', array('event', 'post'));
		}
	endif;
}

// - Show in Portal Calendar
function eop_event_box( $post ) {
	add_meta_box(
		'Portal Cal Event', // ID, should be a string
		__( 'Show events in the feed', 'event-organiser-ngo' ), // Meta Box Title
		'eop_event_box_content', // Your call back function, this is where your form field will go
		'event', // The post type you want this to show up on, can be post, page, or custom post type
		'side', // The placement of your meta box, can be normal or side
		'high' // The priority in which this will be displayed
	);
}

function eop_event_box_content( $post ) {
	global $post;
	$pcustom = get_post_custom($post->ID);
	if ($pcustom) {
//		$event_portal = $pcustom["event_portal"][0];
		$event_portal_value = get_post_meta($post->ID, 'event_portal', true);
		if($event_portal_value == "yes") {
			$event_portal_checked = 'checked="checked"';
		} else {
			$event_portal_checked = "";
		}
	} else {
		$event_portal_checked = "";
	}
	echo ' <input type="checkbox" name="event_portal" value="yes" '.$event_portal_checked.' />';
	?><label><?php _e( 'Show events in the portal calendar', 'event-organiser-ngo'); ?></label><?php
}

function eop_cal_event_save_box( $post_id){
	global $post;
	if ( ! empty($post->ID)) {
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return $post->ID;
		}
		if (isset( $_POST["event-portal"] ) ); {
			if ( ( empty($_POST["event_portal"] ) ) || ( $_POST["event_portal"] == "yes" ) ) {
				update_post_meta($post->ID, "event_portal", $_POST["event_portal"]);
			}
		}
	}
}
// Done Show Events in Feed. Settings -> reading

//////////////////////////////////////////////////////////
/// Widget for one week calendar showing portal events ///
//////////////////////////////////////////////////////////
add_action( 'widgets_init', create_function('', 'return register_widget("PortalOneWeekCalendar");') );
class PortalOneWeekCalendar extends WP_Widget{
	var $w_arg = array(
		'title'								=> 'Events this week', // Translated in __construct
		'showpastevents'			=> 1,
		'event_start_after'		=>'last Monday',
		'event_start_before'	=>'next Sunday'
	);

	function __construct() {
		$widget_ops = array('classname' => 'PortalOneWeekCalendar', 'description' => __('Shows this weeks events.','event-organiser-ngo') );
		$this->w_arg['title'] = __('Events this week', 'event-organiser-ngo');
		parent::__construct('PortalOneWeekCalendar', __('Portal Calendar','event-organiser-ngo'), $widget_ops);
	}

	function form($instance){
		$instance = wp_parse_args( (array) $instance, $this->w_arg );
		?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'event-organiser-ngo'); ?>: </label>
		<input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr($instance['title']); ?>" /></p>
	<?php }

	function update($new_instance, $old_instance){
		$validated=array();
		$validated['title'] = sanitize_text_field( $new_instance['title'] );
		return $validated;
	}

	function widget($args, $instance){
		extract($args, EXTR_SKIP);

		echo $before_widget;

		if (array_key_exists( 'title', $instance ) ) {
			echo $before_title.esc_html($instance['title']).$after_title;
		}

		// set current timestamp
		$today = time();
		// calculate the number of days since Monday
		$dow = date('w', $today);
		$offset = $dow - 1;
		if ($offset < 0) {
			$offset = 6;
		}

		// calculate timestamp for Monday and Sunday
		$monday = $today - ($offset * 86400);
		$tuesday = $monday + (1 * 86400);
		$wednesday = $monday + (2 * 86400);
		$thursday = $monday + (3 * 86400);
		$friday = $monday + (4 * 86400);
		$saturday = $monday + (5 * 86400);
		$sunday = $monday + (6 * 86400);

		$event_days = array($monday, $tuesday, $wednesday, $thursday, $friday, $saturday, $sunday);
		// Get events for portal site
		$event_main = eo_get_events(array(
			//'numberposts'=>5,
			//'post_type'=>'event',
			'event_end_after'=>'last Monday',
			'event_start_before'=>'this Sunday',
			'showpastevents'=>1
		) );

	  echo '<table id="week-calendar">';

		// Set up global variables.
	  global $wpdb, $post;

		// Make sundays stand out...
		foreach ($event_days as $event_day) {
			if ($event_day == $sunday):
				$redday = 'red-day';
			else:
				$redday = '';
			endif;
			echo '<tr><td class="'.$redday.'"><p>'. date_i18n('D', $event_day) .'</p><p>'. date_i18n('j', $event_day) .'</p><p>'. date_i18n('M', $event_day) .'</p></td><td><ul>';

			$blogs = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
			$query['meta_query'] = isset( $query['meta_query'] ) ? $query['meta_query'] : array();
			$query['meta_query'][] = array(
				'key'	 => 'event_portal',
				'value' => yes,
			);

			foreach ($blogs AS $blog) {
			switch_to_blog($blog);
			$events = eo_get_events(array(
//				'numberposts'					=> 5,
				'post_type'						=> 'event',
				'event_end_after'			=> 'last Monday',
				'event_start_before'	=> 'this Sunday',
				'showpastevents'			=> 1,
			) );

				foreach( $events as $post ){
					setup_postdata($post);

					// Show Events in Portal Calendar Widget?
					$id = get_the_id();
					$event_portal = get_post_meta($id, 'event_portal', true);

					if (eo_get_the_start('j') == date("j", $event_day) && $event_portal == 'yes' ) : ?>
						<li><p><?php echo bloginfo('the_title'); ?>:</p><a href='<?php the_permalink() ?>' class="calendar-event-desc"><?php the_title(); ?></a></li>
					<?php endif;
				} // Foreach events as post
				restore_current_blog();
			} // Foreach blog
			echo '</ul></td></tr>';
			// =================================

		} // End foreach events_days
		wp_reset_postdata();
		echo '</table>';
		echo $after_widget;
	}
}
?>
