<?php
// Adds a filter to the portal calendar, that injects the site's events in to the portal calendar, if they choose to share.

add_filter( 'eventorganiser_fullcalendar', 'eongo_insert_portal_events', 10, 2 );

function eongo_insert_portal_events( $events_array, $query ) {

	// If not portal-site, do nothing
	if ( ! is_main_site( $blog_id ) ) {
		return $events_array;
	} else {
		// Empty events_array so we can populate it our way
		$events_array = '';
	}

	// Set up global variables.
	global $wpdb, $post;

	// Get a list of blogs in our multisite network
	$blogs = $wpdb->get_col( "SELECT blog_id FROM $wpdb->blogs" );
//	$original_blog_id = get_current_blog_id();

	$time_format = ! empty( $_GET['timeformat'] ) ? stripslashes( $_GET['timeformat'] ) : get_option( 'time_format' );

	$query['meta_query'] = isset( $query['meta_query'] ) ? $query['meta_query'] : array();
	$query['meta_query'][] = array(
		'key'	 => 'event_portal',
		'value' => yes,
	);

	foreach ( $blogs as $blog ) {
//		skip current blog
// 		if ( $blog == $original_blog_id ) {
//			continue;
//		}

		switch_to_blog( $blog );
		$active = get_option( 'active_plugins' );
		if ( ! in_array( 'event-organiser/event-organiser.php', $active ) ) {
			continue;
		}

		$events = eo_get_events( $query );

		$current_blog = get_blog_details( array( 'blog_id' => $blog ) );
		$blog_name    = $current_blog->blogname;
		//Blog timezone
		$tz = eo_get_blog_timezone();
		//Loop through events
		global $post;
		if ( $events ) :
			foreach ( $events as $post ) :
				setup_postdata( $post );
				$event = array();

				//Title and url
				//$event['title'] = html_entity_decode( $blog_name . ' &ndash; ' . get_the_title( $post->ID ), ENT_QUOTES, 'UTF-8' );
				$event['title'] = html_entity_decode( $blog_name . '&#10;' . get_the_title( $post->ID ), ENT_QUOTES, 'UTF-8' );
				$link = esc_js( get_permalink( $post->ID ) );
				$link = apply_filters( 'eventorganiser_calendar_event_link', $link, $post->ID, $post->occurrence_id );
				$event['url'] = $link;

				//All day or not?
				$event['allDay'] = eo_is_all_day();

				//Get Event Start and End date, set timezone to the blog's timzone
				$event_start		= new DateTime( $post->StartDate . ' ' . $post->StartTime, $tz );
				$event_end			= new DateTime( $post->EndDate . ' ' . $post->FinishTime, $tz );

				if ( $event['allDay'] ) {
					$event_end->modify( '+1 minute' );
				}

				$event['start'] = $event_start->format( 'Y-m-d\TH:i:s' );
				$event['end']	 = $event_end->format( 'Y-m-d\TH:i:s' );

				if ( $event['allDay'] ) {
					$event_end->modify( '-1 minute' );
				}

				//Don't use get_the_excerpt as this adds a link
				$excerpt_length = apply_filters( 'excerpt_length', 55 );
				$description = wp_trim_words( strip_shortcodes( get_the_content() ), $excerpt_length, '...' );
				$date = eo_format_event_occurrence( $post->ID, $post->occurrence_id, 'F j, Y ', $time_format, ' - ', false );
				$description = $date.'</br></br>'.$description;
				$event['description'] = $description;

				//Include venue if this is set
				$venue = eo_get_venue( $post->ID );
				if ( $venue && ! is_wp_error( $venue ) ) {
					$slug = eo_get_venue_slug( $post->ID );
					$event['className'][] = 'venue-' . $slug;//deprecated. use eo-event-venue-{slug}
					$event['venue']			 = $venue;
					$event['venue_slug']	= $slug;
				}

				//Event categories
				$terms = get_the_terms( $post->ID, 'event-category' );
				$event['category'] = array();
				if ( $terms ) :
					foreach ( $terms as $term ) :
						$event['category'][] = $term->slug;
						$event['className'][] = 'category-'.$term->slug;//deprecated. use eo-event-cat-{slug}
					endforeach;
				endif;

				//Event tags
				if ( eventorganiser_get_option( 'eventtag' ) ) {
					$terms = get_the_terms( $post->ID, 'event-tag' );
					$event['tags'] = array();
					if ( $terms && ! is_wp_error( $terms ) ) :
						foreach ( $terms as $term ) :
							$event['tags'][] = $term->slug;
							$event['className'][] = 'tag-'.$term->slug;//deprecated. use eo-event-tag-{slug}
						endforeach;
					endif;
				}
				//Event colour
				$event['textColor'] = '#ffffff'; //default text colour
				if ( eo_get_event_color() ) {
					$event['color'] = eo_get_event_color();
					$event['textColor'] = eo_get_event_textcolor( $event['color'] );
				}

				$events_array[] = $event;
			endforeach;
			wp_reset_postdata();
		endif;
		restore_current_blog();
	}

	return $events_array;
}
