<?php
// + ACTIONS AND FILTERS
// ===========================================================
add_action( 'admin_init', 'eongo_settings_api_init' );	// Show events Yes/No
add_action( 'pre_get_posts','eongo_site_event_in_feed' );		// Custom Posts in feed ( EVENT )
add_action( 'add_meta_boxes', 'eongo_cal_event_box' );		// Custom Meta - Events on Portal
add_action( 'save_post', 'eongo_cal_event_save_box' );		// Custom Meta - Events on Portal
add_action( 'add_meta_boxes', 'eongo_event_feed_box' );		// Custom Meta - Events in Feed
add_action( 'save_post', 'eongo_event_feed_save_box' );		// Custom Meta - Events in Feed
add_filter( 'the_time', 'eongo_timeago' );								// Show days ago, in the_time()


// - Time settings
function eongo_timeago() {
	global $post;
	$date = $post->post_date;
	$time = get_post_time('G', true, $post);
	$time_diff = time() - $time;
	if( $time_diff > 0 && $time_diff < 72*60*60 )
		$display = sprintf( __('%s ago'), human_time_diff( $time ) );
	else
		$display = date_i18n(get_option('date_format'), strtotime($date) );
	return $display;
}

 // ----------------------------------------
 // Show events in feed - settings -> read
 // ----------------------------------------
function eongo_settings_api_init() {
	add_settings_section('eongo_setting_section',
		__( 'Events /Productions /Posts' , 'event-organiser-ngo' ),
		'eongo_setting_section_callback_function',
		'reading');

	add_settings_field('ngo_show_events',
		__( 'Show event in the feed', 'event-organiser-ngo' ),
		'eongo_setting_callback_function',
		'reading',
		'eongo_setting_section');

	add_settings_field('ngo_show_productions',
		__( 'Show production in the feed', 'event-organiser-ngo' ),
		'eongo_prod_setting_callback_function',
		'reading',
		'eongo_setting_section');


	add_settings_field('ngo_show_concerts',
		__( 'View concert in the feed', 'event-organiser-ngo' ),
		'eongo_conc_setting_callback_function',
		'reading',
		'eongo_setting_section');

	register_setting('reading','ngo_show_productions');
	register_setting('reading','ngo_show_events');
	register_setting('reading','ngo_show_concerts');
}

function eongo_setting_section_callback_function() {
	?><p><?php _e( 'Settings for events /productions /posts', 'event-organiser-ngo' );?></p><?php
}

function eongo_setting_callback_function() {
	?><input name="ngo_show_events" id="show_events_in_feed" type="checkbox" value="1" class="code" <?php echo checked( 1, get_option('ngo_show_events'), false ); ?> /> <?php _e( 'Please tick if you wish to show events in the news feed.', 'event-organiser-ngo' );
 }

function eongo_prod_setting_callback_function() {
	?><input name="ngo_show_productions" id="show_prod_in_feed" type="checkbox" value="1" class="code" <?php echo checked( 1, get_option('ngo_show_productions'), false ); ?> /> <?php _e( 'Please tick if you wish to show productions in the news feed.', 'event-organiser-ngo' );
}

function eongo_conc_setting_callback_function() {
	?><input name="ngo_show_concerts" id="show_concert_in_feed" type="checkbox" value="1" class="code" <?php echo checked( 1, get_option('ngo_show_concerts'), false ); ?> /> <?php _e( 'Please tick if you wish to show concerts in the news feed.', 'event-organiser-ngo' );
}
// Done Show Events in Feed. Settings -> reading

// Show the event in the feed (among other posts, not only in calendar)
// Setting shows up on the event page, upper right corner.
function eongo_site_event_in_feed($query){
	$events_feed = get_option('ngo_show_events');
	$prod_feed = get_option('ngo_show_productions');
	$conc_feed = get_option('ngo_show_concerts');
	if ( $events_feed == 1 ) :
		$show_event = 'event';
	else:
		$show_event = '';
	endif;
	if ( $prod_feed == 1 ) :
		$show_prod = 'production';
	else:
		$show_prod = '';
	endif;
	if ( $conc_feed == 1 ) :
		$show_conc = 'concert';
	else:
		$show_conc = '';
	endif;

	if(  !is_admin() && $query->is_main_query() && is_home() ){
		$query->set('post_type', array('post', $show_event, $show_prod, $show_conc));
		// $query->set('meta_key', 'event_feed');
		// $query->set('meta_value', false);
	}

	//if( $query->is_front_page() ){
	//    $query->set('post_type', array('post', $show_event, $show_prod, $show_conc));
	//}

	// if( $query->is_main_query() && is_front_page() ){
	//    $query->set('post_type', array('post', $show_event, $show_prod, $show_conc));
	// }
}

// + CUSTOM META FUNCTIONS FOR EVENT SETTINGS
// ===========================================================

// - Show in Portal Calendar
function eongo_cal_event_box( $post ) {
	add_meta_box(
		'Portal Cal Event', // ID, should be a string
		__( 'Show events in the feed', 'event-organiser-ngo' ), // Meta Box Title
		'eongo_cal_event_box_content', // Your call back function, this is where your form field will go
		'event', // The post type you want this to show up on, can be post, page, or custom post type
		'side', // The placement of your meta box, can be normal or side
		'high' // The priority in which this will be displayed
	);
}

function eongo_cal_event_box_content( $post ) {
	global $post;
	$custom = get_post_custom($post->ID);
	if ($custom) {
//		$event_portal = $custom["event_portal"][0];
		$event_portal_value = get_post_meta($post->ID, 'event_portal', true);
		if($event_portal_value == "yes") {
			$event_portal_checked = 'checked="checked"';
		} else { $event_portal_checked = '';}
	} else { $event_portal_checked = ''; }
		echo ' <input type="checkbox" name="event_portal" value="yes" '.$event_portal_checked.' />';
		?><label><?php _e( 'View events in the portal calendar', 'event-organiser-ngo' ); ?></label><?php
}

function eongo_cal_event_save_box( $post_id){
	global $post;
	if ( ! empty($post->ID)) {
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return $post->ID;
		}
		if ( ( empty($_POST["event_portal"] ) ) || ( $_POST["event_portal"] == "yes" ) ) {
			update_post_meta($post->ID, "event_portal", $_POST["event_portal"]);
		}
	}
}

// - Show in Site Feed
function eongo_event_feed_box( $post ) {
	add_meta_box(
		'Event in feed', // ID, should be a string
		__( 'Hide events in the feed.', 'event-organiser-ngo' ), // Meta Box Title
		'eongo_event_feed_box_content', // Your call back function, this is where your form field will go
		'event', // The post type you want this to show up on, can be post, page, or custom post type
		'side', // The placement of your meta box, can be normal or side
		'high' // The priority in which this will be displayed
	);
}

function eongo_event_feed_box_content( $post ) {
	global $post;
	$custom_two = get_post_custom($post->ID);
	if ($custom_two) {
//		$event_feed = $custom_two["event_feed"][0];
		$event_feed_value = get_post_meta($post->ID, 'event_feed', true);
		if($event_feed_value == "yes") {
			$event_feed_checked = 'checked="checked"';
		}
		else {
			$event_feed_checked = "";
		}
	} else {
		$event_feed_checked = "";
	}
	echo ' <input type="checkbox" name="event_feed" value="yes" '.$event_feed_checked.' />';
	?><label><?php _e( 'Hide events in your own feed.', 'event-organiser-ngo' ); ?></label><?php
}

function eongo_event_feed_save_box( $post_id){
	global $post;
	if ( ! empty($post->ID)) {
		if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
			return $post->ID;
		}
		if ( ( empty($_POST["event_feed"] ) ) || ( $_POST["event_feed"] == "yes" ) ) {
			update_post_meta($post->ID, "event_feed", $_POST["event_feed"]);
		}
	}
}

//  WIDGETS
//===========================================================

//////////////////////////////////
// Widget for one week calendar //
//////////////////////////////////
add_action( 'widgets_init', create_function('', 'return register_widget("NGOOneWeekCalendar");') );
class NGOOneWeekCalendar extends WP_Widget{
	var $w_arg = array(
		'title'=> 'Happening this week', //Translated in __construct
		'showpastevents'=> 1,
			'event_start_after'=>'last Monday',
			'event_start_before'=>'next Sunday'
		);

	function __construct() {
		$widget_ops = array('classname' => 'NGOOneWeekCalendar', 'description' => __('Shows this weeks events.','event-organiser-ngo') );
		$this->w_arg['title'] = __('Happening this week', 'event-organiser-ngo'); // Translation of above title, since it can't be done there
		parent::__construct('NGOOneWeekCalendar', __('NGO Weekly Calendar','event-organiser-ngo'), $widget_ops);
	}

	function form($instance){
		$instance = wp_parse_args( (array) $instance, $this->w_arg );
		?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'event-organiser-ngo'); ?>: </label>
			<input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr($instance['title']); ?>" />
		</p><?php
	}

	function update($new_instance, $old_instance){
		$validated=array();
		$validated['title'] = sanitize_text_field( $new_instance['title'] );
		return $validated;
	}

	function widget($args, $instance){
		extract($args, EXTR_SKIP);

		echo $before_widget;

	if (array_key_exists( 'title', $instance ) ) {
		echo $before_title.esc_html($instance['title']).$after_title;
	}

	$today = time();

	$dow = date('w', $today);
	$offset = $dow - 1;
	if ($offset < 0) {
		$offset = 6;
	}

	$monday = $today - ($offset * 86400);
	$tuesday = $monday + (1 * 86400);
	$wednesday = $monday + (2 * 86400);
	$thursday = $monday + (3 * 86400);
	$friday = $monday + (4 * 86400);
	$saturday = $monday + (5 * 86400);
	$sunday = $monday + (6 * 86400);

	$event_days = array($monday, $tuesday, $wednesday, $thursday, $friday, $saturday, $sunday);

	$events = eo_get_events(array(
	'event_end_before'=>'+2 weeks',
	'event_start_after'=>'last Monday',
	'showpastevents'=>1
	) );

	echo '<table id="week-calendar">';

	global $post;

	foreach ( $event_days as $event_day) {
		if ($event_day == $sunday):
			$redday = 'red-day';
		else:
			$redday = '';
		endif;
		// D = Weekday three letters, j = Day of month , M = Month 3 letters
		echo '<tr><td class="'.$redday.'"><p>'. date_i18n('D', $event_day) .'</p><p>'. date_i18n('j', $event_day) .'</p><p>'. date_i18n('M', $event_day) .'</p></td><td><ul>';
		if( $events ) :
			foreach ($events as $post) {
				if ( eo_get_the_start('j') <> eo_get_the_end('j') ) :
					$start = eo_get_the_start('j');
					$end = eo_get_the_end('j');

					foreach (range($start,$end) as $date) {
						if ($date == $start || $date == $end) :

						else:
							if (($date) == date("j", $event_day)) :
								if ( eo_is_all_day() ) : $fullday = true; endif;
								echo '<li>';
								if ( $fullday == true ) :
									?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em> - <?php _e( 'All day', 'event-organiser-ngo' ); ?></p><?php
								else :
									?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em></p><?php
								endif;
								echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
								echo '</li>';
							endif;
						endif;
					}
				endif;

				if (eo_get_the_start('j') == date("j", $event_day)) :
					if ( eo_get_the_start('j') <> eo_get_the_end('j')):
						if ( eo_is_all_day() ) : $fullday = true; endif;
							echo '<li>';
							if ( isset($fullday) && $fullday == true ) :
								?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em> - <?php _e( 'All day', 'event-organiser-ngo' ); ?></p><?php
							else :
								?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' );?></em> - <?php _e('Start', 'event-organiser-ngo' );?>: <?php echo eo_get_the_start('H:i') . '</p>';
							endif;
							echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
							echo '</li>';
						else:
							if ( eo_is_all_day() ) : $fullday = true; else: $fullday = ''; endif;
								echo '<li>';
								if ( $fullday == true ) :
									?><p><?php _e( 'All day:', 'event-organiser-ngo' ); ?></p><?php
								else :
									echo '<p>' . eo_get_the_start('H:i') . ' - ' . eo_get_the_end('H:i') . '</p>';
								endif;
									echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
									echo '</li>';
							endif;

						elseif (eo_get_the_end('j') == date("j", $event_day)):

							if ( eo_get_the_start('j') <> eo_get_the_end('j')):
								if ( eo_is_all_day() ) : $fullday = true; endif;
									echo '<li>';
									if ( isset($fullday) && $fullday == true ) :
										?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em> - <?php _e( 'All day', 'event-organiser-ngo' ); ?></p><?php
									else :
										?><p><em><?php _e('Multiday Events', 'event-organiser-ngo');?></em> - <?php _e('End', 'event-organiser-ngo');?>: <?php echo eo_get_the_end('H:i') . '</p>';
									endif;
										echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
										echo '</li>';
								endif;
							endif;
			}
		endif;
		echo '</ul></td></tr>';

			wp_reset_postdata();

		}
		echo '</table>';

		echo $after_widget;
	}
}

//////////////////////////////////
// Widget for two week calendar //
//////////////////////////////////
add_action( 'widgets_init', create_function('', 'return register_widget("NGOTwoWeekCalendar");') );

class NGOTwoWeekCalendar extends WP_Widget {

	var $w_arg = array(
	'title'=> 'Current events',
		'showpastevents'=> 1
	);

	function __construct() {
		$widget_ops = array('classname' => 'NGOTwoWeekCalendar', 'description' => __('Showing this & next weeks events.','event-organiser-ngo') );
// Removed down since it does not play well with adding title above.. Not needed?
//    $this->w_arg = array('item_format' => get_option( 'time_format' ),
//    );
		$this->w_arg['title'] = __('Current Events', 'event-organiser-ngo'); // Translation of above title, since it can't be done there
		parent::__construct('NGOTwoWeekCalendar', __('NGO Two week calendar','event-organiser-ngo'), $widget_ops);
	}

	function form($instance){
		$instance = wp_parse_args( (array) $instance, $this->w_arg );
		?><p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title', 'event-organiser-ngo'); ?>: </label>
		<input type="text" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" value="<?php echo esc_attr($instance['title']); ?>" /></p>
	<?php }

	function update($new_instance, $old_instance){
		$validated=array();
		$validated['title'] = sanitize_text_field( $new_instance['title'] );
		return $validated;
	}

	function widget($args, $instance){
		extract($args, EXTR_SKIP);

		echo $before_widget;

		if (array_key_exists( 'title', $instance ) ) {
			echo $before_title.esc_html($instance['title']).$after_title;
		}

		$today = time();
		$dow = date('w', $today);
		$offset = $dow - 1;
		if ($offset < 0) {
				$offset = 6;
		}

		$monday = $today - ($offset * 86400);
		$tuesday = $monday + (1 * 86400);
		$wednesday = $monday + (2 * 86400);
		$thursday = $monday + (3 * 86400);
		$friday = $monday + (4 * 86400);
		$saturday = $monday + (5 * 86400);
		$sunday = $monday + (6 * 86400);
		$mondaytwo = $monday + (7 * 86400);
		$tuesdaytwo = $monday + (8 * 86400);
		$wednesdaytwo = $monday + (9 * 86400);
		$thursdaytwo = $monday + (10 * 86400);
		$fridaytwo = $monday + (11 * 86400);
		$saturdaytwo = $monday + (12 * 86400);
		$sundaytwo = $monday + (13 * 86400);

		$event_days = array($monday, $tuesday, $wednesday, $thursday, $friday, $saturday, $sunday, $mondaytwo, $tuesdaytwo, $wednesdaytwo, $thursdaytwo, $fridaytwo, $saturdaytwo, $sundaytwo);

		$events = eo_get_events(array(
			'event_end_before'=>'+3 weeks',
			'event_start_after'=>'last Monday',
			'showpastevents'=>1
		));

		echo '<table id="week-calendar">';

		global $post;

		foreach ( $event_days as $event_day) {
			if ($event_day == $sunday || $event_day == $sundaytwo):
				$redday = 'red-day';
			else:
				$redday = '';
			endif;
			echo '<tr><td class="'.$redday.'"><p>'. date_i18n('D', $event_day) .'</p><p>'. date_i18n('j', $event_day) .'</p><p>'. date_i18n('M', $event_day) .'</p></td><td><ul>';
			if( $events ) :
				foreach ($events as $post) {
					if ( eo_get_the_start('j') <> eo_get_the_end('j') ) :
						$start = eo_get_the_start('j');
						$end = eo_get_the_end('j');

						foreach (range($start,$end) as $date) {
							if ($date == $start || $date == $end) :

							else:
								if (($date) == date("j", $event_day)) :
									if ( eo_is_all_day() ) : $fullday = true; endif;
									echo '<li>';
									if ( isset($fullday) && $fullday == true ) :
										?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em> - <?php _e( 'All day', 'event-organiser-ngo' ); ?></p><?php
									else :
										?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em></p><?php
									endif;
									echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
									echo '</li>';
								endif;
							endif;
						}
					endif;

					if (eo_get_the_start('j') == date("j", $event_day)) :
						if ( eo_get_the_start('j') <> eo_get_the_end('j')):
							if ( eo_is_all_day() ) : $fullday = true; endif;
								echo '<li>';
								if ( isset($fullday) && ( $fullday == true ) ) :
									?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em> - <?php _e( 'All day', 'event-organiser-ngo' ); ?></p><?php
								else :

									echo '<p><em>Multiday Events</em> - Börjar: ' . eo_get_the_start('H:i') . '</p>';
								endif;
								echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
								echo '</li>';
							else:

							if ( eo_is_all_day() ) : $fullday = true; endif;
								echo '<li>';
								if ( isset($fullday) && $fullday == true ) :
									echo '<p>All day:</p>';
								else :
									echo '<p>' . eo_get_the_start('H:i') . ' - ' . eo_get_the_end('H:i') . '</p>';
								endif;
								echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
								echo '</li>';
							endif;

						elseif (eo_get_the_end('j') == date("j", $event_day)):

							if ( eo_get_the_start('j') <> eo_get_the_end('j')):
								if ( eo_is_all_day() ) : $fullday = true; endif;
									echo '<li>';
										if ( isset($fullday) && ( $fullday == true ) ) :
											?><p><em><?php _e( 'Multiday Events', 'event-organiser-ngo' ); ?></em> - <?php _e( 'All day', 'event-organiser-ngo' ); ?></p><?php
								else :
								?><p><em><?php _e('Multiday Events', 'event-organiser-ngo' );?></em> - <?php _e('End', 'event-organiser-ngo')?>: <?php echo eo_get_the_end('H:i') . '</p>';
							endif;
								echo '<a href="'. get_permalink() .'">'. get_the_title() .'</a>';
								echo '</li>';
						endif;
					endif;
				}
			endif;
			echo '</ul></td></tr>';
			wp_reset_postdata();
		}
		echo '</table>';
		echo $after_widget;
	}
}
// END Widget for two week calendar
?>